@@ -1,7 +1,7 @@
-__version__ = '0.1.3'
+__version__ = '0.2.1'
 
 
-from .interfaces import IMessenger
+from .interfaces import IApos
 from .interfaces import IEvent
 from .interfaces import ICommand
 from .interfaces import IQuery
@@ -10,13 +10,13 @@ from .interfaces import IEventHandler
 from .interfaces import ICommandHandler
 from .interfaces import IQueryHandler
 
-from .core import Messenger
+from .core import Apos
 
 from .exceptions import MissingHandler
 from .exceptions import OverwritingHandler
 
 
-IMessenger
+IApos
 IEvent
 ICommand
 IQuery
@@ -24,6 +24,8 @@ IResponse
 IEventHandler
 ICommandHandler
 IQueryHandler
-Messenger
+Apos
 MissingHandler
 OverwritingHandler
+
+apos = Apos()
